@@ -1,8 +1,14 @@
+"""Migration to add the permissions table.
+"""
+
+# pylint:disable=invalid-name
+
 from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
-
+    """Migration for adding the initial table for providing permissions.
+    """
     initial = True
 
     dependencies = [
@@ -12,7 +18,8 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='GCPIotDevicePermissions',
             fields=[
-                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
+                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False,
+                                        verbose_name='ID')),
             ],
             options={
                 'managed': False,
