@@ -101,7 +101,7 @@ class DevicesViewset(GenericViewSet):
         :return: Fully qualified path to access the device.
         :rtype: str
         """
-        device_id = self.kwargs[self.lookup_url_kwarg]
+        device_id = self.kwargs[self.lookup_field]
         return self.client.device_path(self.config.project, self.config.location,
                                        self.config.registry, device_id)
 
